@@ -34,7 +34,7 @@ from .helpers import get_reason_phrase
 from .route import route_shortcuts
 from .route import route_patch
 from .schemas import Schema
-from .types import ResponseType
+from .types import ResponseReturnValueType
 from .types import ViewFuncType
 from .types import ErrorCallbackType
 from .types import SpecCallbackType
@@ -315,7 +315,7 @@ class APIFlask(Flask):
         self.json_errors = json_errors
 
         self.spec_callback: t.Optional[SpecCallbackType] = None
-        self.error_callback: ErrorCallbackType = self._error_handler  # type: ignore
+        self.error_callback: ErrorCallbackType = self._error_handler
         self.schema_name_resolver = self._schema_name_resolver
 
         self._spec: t.Optional[t.Union[dict, str]] = None
@@ -329,21 +329,28 @@ class APIFlask(Flask):
 
         - Always pass an `HTTPError` instance to error handlers.
         """
-        @self.errorhandler(HTTPError)  # type: ignore
+        @self.errorhandler(HTTPError)
         def handle_http_errors(
             error: HTTPError
-        ) -> ResponseType:
+        ) -> ResponseReturnValueType:
             return self.error_callback(error)
 
         if self.json_errors:
             @self.errorhandler(WerkzeugHTTPException)  # type: ignore
             def handle_werkzeug_errors(
-                error: WerkzeugHTTPException
-            ) -> ResponseType:
-                error = HTTPError(error.code, error.name)  # type: ignore
+                e: WerkzeugHTTPException
+            ) -> ResponseReturnValueType:
+                headers = dict(e.get_headers())
+                # remove the original MIME header
+                del headers['Content-Type']
+                error = HTTPError(
+                    e.code,
+                    message=e.name,
+                    headers=headers
+                )
                 return self.error_callback(error)
 
-    def dispatch_request(self) -> ResponseType:
+    def dispatch_request(self) -> ResponseReturnValueType:
         """Overwrite the default dispatch method in Flask.
 
         With this overwrite, view arguments are passed as positional
@@ -388,22 +395,21 @@ class APIFlask(Flask):
     @staticmethod
     def _error_handler(
         error: HTTPError
-    ) -> t.Union[t.Tuple[dict, int], t.Tuple[dict, int, t.Mapping[str, str]]]:
+    ) -> ResponseReturnValueType:
         """The default error handler.
 
         Arguments:
-            status_code: The status code of the error (4XX and 5xx).
-            message: The simple description of the error. If not provided,
-                the reason phrase of the status code will be used.
-            detail: The detailed information of the error, you can use it to
-                provide the addition information such as custom error code,
-                documentation URL, etc.
-            headers: A dict of headers used in the error response.
+            error: An instance of [`HTTPError`][apiflask.exceptions.HTTPError].
+
+        *Version changed: 0.10.0*
+
+        - Remove the `status_code` field from the response.
+        - Add `HTTPError.extra_data` to the reponse body.
         """
         body = {
             'detail': error.detail,
             'message': error.message,
-            'status_code': error.status_code
+            **error.extra_data
         }
         return body, error.status_code, error.headers
 
@@ -411,11 +417,12 @@ class APIFlask(Flask):
         self,
         f: ErrorCallbackType
     ) -> ErrorCallbackType:
-        """A decorator to register an error response processor function.
+        """A decorator to register a custom error response processor function.
 
         The decorated callback function will be called in the following situations:
 
-        - An validation error happened when parsing a request.
+        - Any HTTP exception is raised by Flask when `APIFlask(json_errors=True)` (default).
+        - A validation error happened when parsing a request.
         - An exception triggered with [`HTTPError`][apiflask.exceptions.HTTPError]
         - An exception triggered with [`abort`][apiflask.exceptions.abort].
 
@@ -438,23 +445,24 @@ class APIFlask(Flask):
             return {
                 'status_code': error.status_code,
                 'message': error.message,
-                'detail': error.detail
+                'detail': error.detail,
+                **error.extra_data
             }, error.status_code, error.headers
         ```
 
         The error object is an instance of [`HTTPError`][apiflask.exceptions.HTTPError],
         so you can get error information via it's attributes:
 
-        - status_code: If the error triggered by validation error, the value will be
-            400 (default) or the value you passed in config `VALIDATION_ERROR_STATUS_CODE`.
-            If the error triggered by [`HTTPError`][apiflask.exceptions.HTTPError]
-            or [`abort`][apiflask.exceptions.abort], it will be the status code
-            you passed. Otherwise, it will be the status code set by Werkzueg when
-            processing the request.
-        - message: The error description for this error, either you passed or grab from
-            Werkzeug.
-        - detail: The detail of the error. When the validation error happened, it will
-            be filled automatically in the following structure:
+        - status_code: If the error is triggered by a validation error, the value will be
+          400 (default) or the value you passed in config `VALIDATION_ERROR_STATUS_CODE`.
+          If the error is triggered by [`HTTPError`][apiflask.exceptions.HTTPError]
+          or [`abort`][apiflask.exceptions.abort], it will be the status code
+          you passed. Otherwise, it will be the status code set by Werkzueg when
+          processing the request.
+        - message: The error description for this error, either you passed or grabbed from
+          Werkzeug.
+        - detail: The detail of the error. When the validation error happens, it will
+          be filled automatically in the following structure:
 
             ```python
             "<location>": {
@@ -468,17 +476,19 @@ class APIFlask(Flask):
             ...
             ```
 
-            The value of `location` can be `json` (i.e., request body) or `query`
-            (i.e., query string) depend on the place where the validation error
-            happened.
-        - headers: The value will be `None` unless you pass it in HTTPError or abort.
+          The value of `location` can be `json` (i.e., request body) or `query`
+          (i.e., query string) depending on the place where the validation error
+          happened.
+        - headers: The value will be `{}` unless you pass it in `HTTPError` or `abort`.
+        - extra_data: Additional error information.
 
         If you want, you can rewrite the whole response body to anything you like:
 
         ```python
         @app.error_processor
         def my_error_processor(error):
-            return {'error_detail': error.detail}, error.status_code, error.headers
+            body = {'error_detail': error.detail, **error.extra_data}
+            return body, error.status_code, error.headers
         ```
 
         However, I would recommend keeping the `detail` in the response since it contains
@@ -513,7 +523,7 @@ class APIFlask(Flask):
 
         if self.spec_path:
             @bp.route(self.spec_path)
-            def spec() -> ResponseType:
+            def spec() -> ResponseReturnValueType:
                 if self.config['SPEC_FORMAT'] == 'json':
                     response = jsonify(self._get_spec('json'))
                     response.mimetype = self.config['JSON_SPEC_MIMETYPE']
@@ -705,6 +715,11 @@ class APIFlask(Flask):
     def _generate_spec(self) -> APISpec:
         """Generate the spec, return an instance of `apispec.APISpec`.
 
+        *Version changed: 0.10.0*
+
+        - Add support for `operationId`.
+        - Add support for response `links`.
+
         *Version changed: 0.9.0*
 
         - Add base response customization support.
@@ -902,6 +917,15 @@ class APIFlask(Flask):
                 if view_func._spec.get('deprecated'):
                     operation['deprecated'] = view_func._spec.get('deprecated')
 
+                # operationId
+                operation_id = view_func._spec.get('operation_id')
+                if operation_id is None:
+                    if self.config['AUTO_OPERATION_ID']:
+                        operation['operationId'] = \
+                            f"{method.lower()}_{rule.endpoint.replace('.', '_')}"
+                else:
+                    operation['operationId'] = operation_id
+
                 # responses
                 if view_func._spec.get('response'):
                     schema = view_func._spec.get('response')['schema']
@@ -930,8 +954,9 @@ class APIFlask(Flask):
                         self.config['SUCCESS_DESCRIPTION']
                     example = view_func._spec.get('response')['example']
                     examples = view_func._spec.get('response')['examples']
+                    links = view_func._spec.get('response')['links']
                     add_response(
-                        operation, status_code, schema, description, example, examples
+                        operation, status_code, schema, description, example, examples, links
                     )
                 else:
                     # add a default 200 response for views without using @output
