@@ -9,7 +9,7 @@ class FooSchema(Schema):
     class Meta:
         unknown = EXCLUDE
 
-    id = Integer(default=123)
+    id = Integer(dump_default=123)
     name = String(required=True)
 
 
@@ -17,12 +17,12 @@ class BarSchema(Schema):
     class Meta:
         unknown = EXCLUDE
 
-    id2 = Integer(default=123)
+    id2 = Integer(dump_default=123)
     name2 = String(required=True)
 
 
 class BazSchema(Schema):
-    id = Integer(default=123)
+    id = Integer(dump_default=123)
     name = String()
 
 
@@ -30,22 +30,22 @@ class QuerySchema(Schema):
     class Meta:
         unknown = EXCLUDE
 
-    id = Integer(missing=1)
+    id = Integer(load_default=1)
 
 
 class PaginationSchema(Schema):
     class Meta:
         unknown = EXCLUDE
 
-    page = Integer(missing=1)
-    per_page = Integer(missing=10)
+    page = Integer(load_default=1)
+    per_page = Integer(load_default=10)
 
 
 class HeaderSchema(Schema):
     class Meta:
         unknown = EXCLUDE
 
-    foo = String(missing='bar')
+    foo = String(load_default='bar')
 
 
 class ValidationErrorSchema(Schema):
